@@ -1,10 +1,10 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ---- eval = FALSE------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  install.packages("gtfs2gps")
 
 ## -----------------------------------------------------------------------------
@@ -14,10 +14,9 @@ names(poa)
 head(poa$trips)
 
 ## -----------------------------------------------------------------------------
-library(magrittr)
-object.size(poa) %>% format(units = "Kb")
+object.size(poa) |> format(units = "Kb")
 poa_small <- gtfstools::filter_by_shape_id(poa, c("T2-1", "A141-1"))
-object.size(poa_small) %>% format(units = "Kb")
+object.size(poa_small) |> format(units = "Kb")
 
 ## ----poa_small_shapes_sf, message = FALSE-------------------------------------
 poa_small_shapes_sf <- gtfs2gps::gtfs_shapes_as_sf(poa_small)
@@ -26,16 +25,16 @@ plot(sf::st_geometry(poa_small_shapes_sf))
 plot(sf::st_geometry(poa_small_stops_sf), pch = 20, col = "red", add = TRUE)
 box()
 
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 temp_gtfs <- tempfile(pattern = 'poa_small', fileext = '.zip')
 
 gtfs2gps::write_gtfs(poa_small, temp_gtfs)
 
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 poa_gps <- gtfs2gps(temp_gtfs, spatial_resolution = 100)
 head(poa_gps)
 
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 poa_gps60 <- poa_gps[1:100, ]
 
 # points
@@ -49,7 +48,7 @@ plot(sf::st_geometry(poa_gps60_sfpoints), pch = 20)
 plot(sf::st_geometry(poa_gps60_sflinestring), col = "blue", add = TRUE)
 box()
 
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 poa <- system.file("extdata/poa.zip", package ="gtfs2gps")
 
 poa_gps <- gtfs2gps(poa, spatial_resolution = 50)
